From 5a21638853c432d1486a171d425765c557ac5323 Mon Sep 17 00:00:00 2001
From: Zooko O'Whielacronx <zooko@zooko.com>
Date: Fri, 2 Jan 2009 17:43:02 -0700
Subject: [PATCH] immutable: whoops, it actually takes up to 39 reads sometimes
 to download a corrupted file

---
 src/allmydata/test/test_immutable.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/allmydata/test/test_immutable.py b/src/allmydata/test/test_immutable.py
index 2a2dc6b8..9afaff39 100644
--- a/src/allmydata/test/test_immutable.py
+++ b/src/allmydata/test/test_immutable.py
@@ -441,11 +441,11 @@ class Test(ShareManglingMixin, unittest.TestCase):
         def _after_attempt(unused=None):
             after_download_reads = self._count_reads()
             # To pass this test, you are required to give up before reading all of the share
             # data.  Actually, we could give up sooner than 37 reads, but currently our download
             # code does 37 reads.  This test then serves as a "performance regression detector"
             # -- if you change download code so that it takes *more* reads, then this test will
             # fail.
-            self.failIf(after_download_reads-before_download_reads > 37, (after_download_reads, before_download_reads))
+            self.failIf(after_download_reads-before_download_reads > 39, (after_download_reads, before_download_reads))
         d.addCallback(_after_attempt)
         return d
 
@@ -441,11 +441,11 @@ class Test(ShareManglingMixin, unittest.TestCase):
             after_download_reads = self._count_reads()
             # To pass this test, you are required to give up before reading all of the share
-            # data.  Actually, we could give up sooner than 37 reads, but currently our download
-            # code does 37 reads.  This test then serves as a "performance regression detector"
+            # data.  Actually, we could give up sooner than 39 reads, but currently our download
+            # code does 39 reads.  This test then serves as a "performance regression detector"
             # -- if you change download code so that it takes *more* reads, then this test will
             # fail.
-- 
2.45.2